@@ -11,7 +11,7 @@ class EmailService(BaseService):
         return self.call("getOptStatus", email)
 
     def optout_email(self, email, reason):
-        return self.call("optOut", email)
+        return self.call("optOut", email, reason)
 
     def optin_email(self, email, reason):
         return self.call("optIn", email)
